## What's Changed

1. 修复使用非默认配置文件情况下时，第三方 Agent Runner (Dify、Coze、阿里云百炼应用等)无法正常工作的问题
2. 修复当“聊天模型”未设置，并且模型提供商中仅有 Agent Runner 时，无法正常使用 Agent Runner 的问题
3. 修复部分情况下报错 `pydantic_core._pydantic_core.ValidationError: 1 validation error for Message content` 的问题
4. 新增群聊模式下的专用图片转述模型配置 ([#3822](https://github.com/AstrBotDevs/AstrBot/issues/3822))

---

重构：
- 将 Dify、Coze、阿里云百炼应用等 LLMOps 提供商迁移到 Agent 执行器层，理清和本地 Agent 执行器的边界。详见：[Agent 执行器](https://docs.astrbot.app/use/agent-runner.html)
- 将「会话管理」功能重构为「自定义规则」功能，理清和多配置文件功能的边界。详见：[自定义规则](https://docs.astrbot.app/use/custom-rules.html)

优化：
- Dify、阿里云百炼应用支持流式输出
- 防止分段回复正则表达式解析错误导致消息不发送
- 群聊上下文感知记录 At 信息
- 优化模型提供商页面的测试提供商功能

新增：
- 支持在配置文件页面快速测试对话
- 为配置文件配置项内容添加国际化支持

修复：
- 在更新 MCP Server 配置后，MCP 无法正常重启的问题
